pub fn halving(height: Height, network: &Network) -> u32Expand description
The halving index for a block height and network.
Halving(height), as described in protocol specification 7.8
pub fn halving(height: Height, network: &Network) -> u32The halving index for a block height and network.
Halving(height), as described in protocol specification 7.8