pub struct FundingStreams {
height_range: Range<Height>,
recipients: HashMap<FundingStreamReceiver, FundingStreamRecipient>,
}Expand description
Funding stream recipients and height ranges.
Fields
height_range: Range<Height>Start and end Heights for funding streams as described in protocol specification 7.10.1.
recipients: HashMap<FundingStreamReceiver, FundingStreamRecipient>Funding stream recipients by FundingStreamReceiver.
Implementations
Sourceimpl FundingStreams
impl FundingStreams
Sourcepub fn new(
height_range: Range<Height>,
recipients: HashMap<FundingStreamReceiver, FundingStreamRecipient>,
) -> Self
pub fn new( height_range: Range<Height>, recipients: HashMap<FundingStreamReceiver, FundingStreamRecipient>, ) -> Self
Creates a new FundingStreams.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Creates a new empty FundingStreams representing no funding streams.
Sourcepub fn height_range(&self) -> &Range<Height>
pub fn height_range(&self) -> &Range<Height>
Returns height range where these FundingStreams should apply.
Sourcepub fn recipients(
&self,
) -> &HashMap<FundingStreamReceiver, FundingStreamRecipient>
pub fn recipients( &self, ) -> &HashMap<FundingStreamReceiver, FundingStreamRecipient>
Returns recipients of these FundingStreams.
Sourcepub fn recipient(
&self,
receiver: FundingStreamReceiver,
) -> Option<&FundingStreamRecipient>
pub fn recipient( &self, receiver: FundingStreamReceiver, ) -> Option<&FundingStreamRecipient>
Returns a recipient with the provided receiver.
Sourcepub fn extend_recipient_addresses(&mut self, target_len: usize)
pub fn extend_recipient_addresses(&mut self, target_len: usize)
Accepts a target number of addresses that all recipients of this funding stream
except the FundingStreamReceiver::Deferred receiver should have.
Extends the addresses for all funding stream recipients by repeating their existing addresses until reaching the provided target number of addresses.