pub trait ParameterSubsidy {
// Required methods
fn height_for_first_halving(&self) -> Height;
fn post_blossom_halving_interval(&self) -> HeightDiff;
fn pre_blossom_halving_interval(&self) -> HeightDiff;
fn funding_stream_address_change_interval(&self) -> HeightDiff;
}Expand description
Functionality specific to block subsidy-related consensus rules
Required Methods
Sourcefn height_for_first_halving(&self) -> Height
fn height_for_first_halving(&self) -> Height
Returns the minimum height after the first halving as described in protocol specification 7.10
Sourcefn post_blossom_halving_interval(&self) -> HeightDiff
fn post_blossom_halving_interval(&self) -> HeightDiff
Returns the halving interval after Blossom
Sourcefn pre_blossom_halving_interval(&self) -> HeightDiff
fn pre_blossom_halving_interval(&self) -> HeightDiff
Returns the halving interval before Blossom
Sourcefn funding_stream_address_change_interval(&self) -> HeightDiff
fn funding_stream_address_change_interval(&self) -> HeightDiff
Returns the address change interval for funding streams as described in protocol specification 7.10.
FSRecipientChangeInterval := PostBlossomHalvingInterval / 48
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl ParameterSubsidy for Network
Network methods related to Block Subsidy and Funding Streams